@@ -6,9 +6,10 @@
  * MIT License <https://github.com/nodejs/nan/blob/master/LICENSE.md>
  ********************************************************************/
 
-#include "sleep.h"
 #include <nan.h>
 
+#include "sleep.h"  // NOLINT(build/include)
+
 using namespace Nan;  // NOLINT(build/namespaces)
 
 class SleepWorker : public AsyncWorker {
