@@ -10,13 +10,16 @@
 
 using namespace Nan;  // NOLINT(build/namespaces)
 
+static AsyncResource* async_resource;
 static Persistent<v8::Function> cb;
 
 void weakCallback(
     const WeakCallbackInfo<int> &data) {  // NOLINT(runtime/references)
   int *parameter = data.GetParameter();
   v8::Local<v8::Value> val = New(*parameter);
-  MakeCallback(GetCurrentContext()->Global(), New(cb), 1, &val);
+  async_resource->runInAsyncScope(
+      GetCurrentContext()->Global(), New(cb), 1, &val);
+  delete async_resource;
   delete parameter;
 }
 
@@ -31,6 +34,7 @@ v8::Local<v8::String> wrap(v8::Local<v8::Function> func) {
 }
 
 NAN_METHOD(Hustle) {
+  async_resource = new AsyncResource("nan:test:weak");
   cb.Reset(To<v8::Function>(info[1]).ToLocalChecked());
   info.GetReturnValue().Set(wrap(To<v8::Function>(info[0]).ToLocalChecked()));
 }
